#include <xc.h>
#include <stdint.h>

#define sF_LED  sGPIO.GP2           // flashing LED (shadow)

volatile union {                    // shadow copy of GPIO
    uint8_t         port;
    struct {
        unsigned    GP0     : 1;
        unsigned    GP1     : 1;
        unsigned    GP2     : 1;
        unsigned    GP3     : 1;
        unsigned    GP4     : 1;
        unsigned    GP5     : 1;
    };
} sGPIO;

void main() {
    GPIO = 0;                       // start with all LEDs off
    sGPIO.port = 0;                 //   update shadow
    TRISIO = ~(1<<2);               // configure GP2 (only) as an output
    OPTION_REGbits.T0CS = 0;        // select timer mode
    OPTION_REGbits.PSA = 1;         // no prescaler -> increment every 1 us
    INTCONbits.T0IE = 1;            // enable Timer0 interrupt
    ei();                           // enable global interrupts
                                    
    for (;;) {
        GPIO = sGPIO.port;          // continually copy shadow GPIO to port          
    }                               // repeat forever
}

void interrupt isr(void)            // Interrupt service
{
    static uint16_t  cnt_t0 = 0;    // counts timer0 overflows
    TMR0 += 256-250+3;              // add value to Timer0 for overflow after 250 counts
    INTCONbits.T0IF = 0;            // clear interrupt flag
    ++cnt_t0;                       // increment interrupt count (every 250 us)
    if (cnt_t0 == 500000/250) {     // if count overflow (every 500 ms),
        cnt_t0 = 0;                 //   reset count
        sF_LED = ~sF_LED;           //   toggle LED (via shadow register)
    }
}
