#include <xc.h>
#include <stdint.h>

#pragma config FOSC = INTOSCIO  // Oscillator Selection bits (INTOSCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN)
#pragma config WDTE = OFF       // Watchdog Timer Enable bit (WDT disabled)
#pragma config PWRTE = ON       // Power-up Timer Enable bit (PWRT enabled)
#pragma config MCLRE = OFF      // MCLR Pin Function Select bit (MCLR pin function is digital input, MCLR internally tied to VDD)
#pragma config CP = OFF         // Code Protection bit (Program memory code protection is disabled)
#pragma config CPD = OFF        // Data Code Protection bit (Data memory code protection is disabled)
#pragma config BOREN = OFF      // Brown Out Detect (BOR disabled)
#pragma config IESO = OFF       // Internal External Switchover bit (Internal External Switchover mode is disabled)
#pragma config FCMEN = OFF      // Fail-Safe Clock Monitor Enabled bit (Fail-Safe Clock Monitor is disabled)

#define _XTAL_FREQ  4000000     // oscillator frequency for _delay(
#define START   GPIObits.GP2        // LEDs
#define SUCCESS GPIObits.GP1
#define BUTTON  GPIObits.GP3        // pushbutton
#define MAXRT   200                 // Maximum reaction time in ms
void main() {
    uint8_t     cnt_8ms;            // counter: increments every 8 ms
    TRISIO = 0b111001;              // configure GP1 and GP2 as outputs
    OPTION_REGbits.T0CS = 0;        // select timer mode
    OPTION_REGbits.PSA = 0;         // assign prescaler to Timer0
    OPTION_REGbits.PS = 0b100;      // prescale = 32
                                    // -> increment every 32 us                              
    for (;;)  {
        GPIO = 0;                   // initialyy both LEDs are off               
        __delay_ms(2000);           // delay 2000 ms             
        START = 1;                  // turn on start LED
        cnt_8ms = 0;
        while (BUTTON == 1 && cnt_8ms < 1000/8)
        {
            TMR0 = 0;               // clear timer0
            while (TMR0 < 8000/32)  // wait for 8 ms (32 us/tick)
                ;
            ++cnt_8ms;              // increment 8 ms counter
        }
        if (cnt_8ms < MAXRT/8)      // if time < max reaction time (8 ms/count)
            SUCCESS = 1;            //   turn on success LED
        __delay_ms(1000);           // delay 1000 ms     
    }  
}

