/* 
 * File:   main.c
 * Author: Henry Chung
 * Link: http://bzzt.io/posts/understanding-the-usart-on-8-bit-pic-microcontrollers-using-xc8
 *
 * Adopted for the PIC16F690 by Istvan Cserny
 * 
 */

// CONFIG
#pragma config FOSC = INTRCIO   // Oscillator Selection bits (INTOSCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN)
#pragma config WDTE = OFF       // Watchdog Timer Enable bit (WDT disabled and can be enabled by SWDTEN bit of the WDTCON register)
#pragma config PWRTE = ON       // Power-up Timer Enable bit (PWRT enabled)
#pragma config MCLRE = ON       // MCLR Pin Function Select bit (MCLR pin function is MCLR)
#pragma config CP = OFF         // Code Protection bit (Program memory code protection is disabled)
#pragma config CPD = OFF        // Data Code Protection bit (Data memory code protection is disabled)
#pragma config BOREN = OFF      // Brown-out Reset Selection bits (BOR disabled)
#pragma config IESO = OFF       // Internal External Switchover bit (Internal External Switchover mode is disabled)
#pragma config FCMEN = OFF      // Fail-Safe Clock Monitor Enabled bit (Fail-Safe Clock Monitor is disabled)

#include <xc.h>
#include <stdio.h>
#include <stdlib.h>
#include "usart.h"

void main() {
    unsigned char input;
    INTCON=0;                      // disable interrupts
    ANSELH &= ~_ANSELH_ANS11_MASK; // configure RX for IO

    // config for serial comms is set in init_comms
    init_comms();

    for(;;) {
        printf("\rPress a key and I will echo it back\n");
        input = getch();
        printf("\rIt was [%c]\n", input);
    }
}
